/* **********************************************************
 * Copyright 2000 VMware, Inc.  All rights reserved.
 * **********************************************************/

/* 
 * os.h --
 *
 * 	Definitions for OS-specific wrapper functions required
 *	by "vmmemctl".  This allows customers to build their own
 *	vmmemctl driver for custom versioned kernels without the
 *	need for source code. 
 */

#ifndef	OS_H
#define	OS_H

/*
 * Needs fixing for 64bit OSes
 */
#ifndef __x86_64__
#define CDECL __attribute__((cdecl, regparm(0)))
#else
#define CDECL
#endif

/*
 * Types
 */

typedef void CDECL (*os_timer_handler)(void *);
typedef int  CDECL (*os_status_handler)(char *);

/*
 * Operations
 */

extern void CDECL *os_kmalloc_atomic(unsigned int size);
extern void CDECL os_kfree(void *obj, unsigned int size);
extern void CDECL os_bzero(void *s, unsigned int n);
extern void CDECL os_memcpy(void *dest, const void *src, unsigned int size);
extern int  CDECL os_sprintf(char *str, const char *format, ...);

extern unsigned long CDECL os_addr_to_ppn(unsigned long addr);
extern unsigned long CDECL os_alloc_reserved_page(void);
extern void          CDECL os_free_reserved_page(unsigned long page);

extern void CDECL os_timer_init(os_timer_handler handler, void *data, int period);
extern void CDECL os_timer_start(void);
extern void CDECL os_timer_stop(void);

extern void CDECL os_init(const char *name,
                          const char *name_verbose,
                          os_status_handler handler);
extern void CDECL os_cleanup(void);

extern char CDECL *os_identity(void);

extern unsigned int CDECL os_predict_max_balloon_pages(void);

extern unsigned int CDECL os_timer_hz(void);

#endif  /* OS_H */
